@@ -201,8 +201,7 @@ int main(int argc, char *argv[]){
 		}
 
 		// Initialize the random number generator
-		int timeSeed = time(NULL);
-		srand(timeSeed);
+		srand ( unsigned ( time(0) ) );
 
 		// If printing out CSV, print a header
 		if (printStyle == SudokuBoard::CSV){
@@ -275,7 +274,7 @@ int main(int argc, char *argv[]){
 					havePuzzle = false;
 					done = true;
 				}
-				delete puzzle;
+				delete[] puzzle;
 			}
 
 			int solutions = 0;
@@ -473,7 +472,7 @@ void printHelp(){
 	cout << "  --one-line           Print puzzles on one line of 81 characters" << endl;
 	cout << "  --compact            Print puzzles on 9 lines of 9 characters" << endl;
 	cout << "  --readable           Print puzzles in human readable form (default)" << endl;
-	cout << "  --csv                Ouput CSV format with one line puzzles" << endl;
+	cout << "  --csv                Output CSV format with one line puzzles" << endl;
 	cout << "  --help               Print this message" << endl;
 	cout << "  --about              Author and license information" << endl;
 	cout << "  --version            Display current version number" << endl;
